/*#############################################################
File Name       : ex1_ColorClick_measure_swv.c
Author          : Grant Phillips
Date Modified   : 18/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  a ColorClick Color Sensor Module.
									
									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F4-Discovery Board
									* Make sure the ColorClick_F4.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									* The ColorClick Color Sensor Module is 
										connected as:
										GND			-		GND
										+3.3V		-		3V
										+5V			-		5V
										SDA			-		PB9  (I2C1_SDA)
										SCL			-		PB6  (I2C1_SCL)
										RD			-		PD8  (RED LED)
										GR			-		PD9  (GREEN LED)
										BL			-		PD10 (BLUE LED)
								
***************************************************************
NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB 
***************************************************************
The ColorClick_F4.c library makes use of floating point variables
which would normally be done by the hardware FPU of the STM32F4, 
but the Evaluation copy of Keil uVision does not support hardware
FPU and will make a program "freeze" when it does floating point
calculations.

To disable hardware FPU support and let the software handle the
floating point calculations (which will obviously decrease the
computational speed of the STM32F4), do the following:
1.  Right-click on "Demo" in the Project window and select
		"Option for Target Demo..."
2.  Select the "Target" tab
3.  Under "Floating Point Hardware", select "Not used"
4.  Click OK

The code can now be compiled and run like normal.
		
***************************************************************
NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB 
***************************************************************

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "ColorClick_F4.c"																			//for the ColorClick Color Sensor Module functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{ 
	RCC_ClocksTypeDef 			RCC_Clocks;									//structure used for setting up the SysTick Interrupt
	
	uint16_t red, green, blue, clear;
	float red_norm, green_norm, blue_norm;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																					//will end up in this infinite loop if there was an error with Systick_Config
	
	Color_Init();																				//initialize the ColorClick module

	Color_SetRGBLeds(1,1,1);														//turn ON the RED, GREEN and BLUE leds to create a white light
		
	/* Main program loop */
	while(1)
	{
    // Read Clear, Red, Green and Blue channel register values
    clear = Color_ReadCData();
		red = Color_ReadRData();
		green = Color_ReadGData();
		blue = Color_ReadBData();
		
		// Calculate the normalized values for more accurate representation of the color
		red_norm = (float)red/(float)clear;					//the (float) casts/converts the variable value to a float so that
		green_norm = (float)green/(float)clear;			//it can be used for floating point calculations
		blue_norm = (float)blue/(float)clear;
		
		// Display the the color values and the normalized values
		printf("R=%5d    G=%5d    B=%5d    C=%5d       R/C=%5.2f    G/C=%5.2f    B/C=%5.2f\n", red, green, blue, clear, red_norm, green_norm, blue_norm);
		
		Delay(1000);		//create a delay so that ColorClick sensor can prepare for a next sample
  }
}



/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}
