/*#############################################################
File Name       : ex1_DHT11_measure_swv
Author          : Grant Phillips
Date Modified   : 15/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  a DHT11 Humidity-Temperature Sensor.  
									DHT11_Init() initializes the sensor and
									DHT11_Read() reads the new results into global
									variables DHT11_Humidity and DHT11_Temperature.
									DHT11_Read() can only be called in 1 second or
									more intervals, otherwise TIMEOUT errors will
									occurr as the DHT11 will not be ready to send
									new data.  TIM9 is used in the DHT11_F4.c 
									library, but could be changed to any other
									timer, as well as the data pin.
									
									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F4-Discovery Board
									* Make sure the DHT11_F4.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									* The DHT11 sensor connected as:
										1. VCC			-		3V
										2. DATA			-		PE15	(with a 5K6 pull-up 
																		resistor to 3V; pin is 5V tolerant)
										3. NC				-		Not connected
										4. GND			-		GND

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "DHT11_F4.c"																						//for the DHT11 humidity-temperature sensor functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config

	DHT11_Init();																									//initialize the DHT11 humidity-temperature sensor

	/* Main program loop */
  while (1)
  {
		if(DHT11_Read() == DHT11_OK)																//read from the DHT11 sensor and check if the result is OK
		{
			printf("Humidity = %d     Temperature = %d\n", DHT11_Humidity, DHT11_Temperature);	//display the results if result is OK
		}
		Delay(1000);
  }	
}


/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}

