/*#############################################################
File Name       : ex1_HMC6352_measure_swv.c
Author          : Grant Phillips
Date Modified   : 13/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  a HMC6352 Compass Module.
									
									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F4-Discovery Board
									* Make sure the HMC6352_F4.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									* The HMC6352 Compass Module is connected as:
										GND		-		GND
										VCC		-		3V
										SDA		-		PB9 (I2C1_SDA)
										SCL		-		PB6 (I2C1_SCL)
										
See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "HMC6352_F4.c"																					//for the HMC6352 compass module functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{ 
	RCC_ClocksTypeDef 			RCC_Clocks;									//structure used for setting up the SysTick Interrupt
	
	int heading;																				//a 16-bit int to hold the distance value
	unsigned int dec, frac;															//used for converting the integer distance to a float value for printing
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																					//will end up in this infinite loop if there was an error with Systick_Config
	
	HMC6352_Init();																			//initialize the HMC6352 compass module
	
	/* Main program loop */
  while(1)
	{
		/* The raw heading value can be 0 (0.0 degrees) to 3600 (360.0 degrees), i.e. 3456 = 345.6 degrees 
			 Read the heading takes 10ms */
		heading = HMC6352_ReadHeading();									//read the heading from the HMC6352 compass module
		if(heading == -1)										//if problem reading from compass
		{
			printf("Error reading from compass!\n");
		}
		else																//no error
		{
			dec = heading / 10;																//calculate the integer part
			frac = heading % dec;															//calculate the fraction part
			
			printf("Raw heading value = %d    %d.%02d degrees\n", heading, dec, frac);	//%02d prints a integer value in a field of 2 characters with leading 0's
			Delay(100);
		}
  }	
}



/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}
