/*#############################################################
File Name       : ex1_ISL29125_measure_swv.c
Author          : Grant Phillips
Date Modified   : 07/06/2015
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  a ISL29125 Color Sensor Module.  An attempt
									is also made to detect the actual color of
									an object, but it seems like the BLUE color
									detection is a problem - needs a bit of work.
									
									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F4-Discovery Board
									* Make sure the ISL29125_F4.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									* The ColorClick Color Sensor Module is 
										connected as:
										GND			-		GND
										+3.3V		-		3V
										SDA			-		PB9  (I2C1_SDA)
										SCL			-		PB6  (I2C1_SCL)

								
See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "ISL29125_F4.c"																			//for the ColorClick Color Sensor Module functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{ 
  uint8_t rcv;
	RCC_ClocksTypeDef 			RCC_Clocks;									//structure used for setting up the SysTick Interrupt
		
	uint16_t red, green, blue;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																					//will end up in this infinite loop if there was an error with Systick_Config
	
	rcv = ISL29125_Init();															//initialize the ISL29125 Color Sensor module
	if (rcv != 0)
		printf("Error initializing the ISL29125 Color Sensor");
	
	ISL29125_Config(CFG1_MODE_RGB | CFG1_10KLUX, CFG2_IR_ADJUST_HIGH, CFG_DEFAULT);			//Set to RGB mode, 10k lux, and high IR compensation 
	//ISL29125_Config(CFG1_MODE_RGB | CFG1_375LUX, CFG2_IR_ADJUST_HIGH, CFG_DEFAULT);		//Set to RGB mode, 375 lux, and high IR compensation - supposed to be better for dark areas
	
	/* Main program loop */
	while(1)
	{
    // Read Clear, Red, Green and Blue channel register values
		red = ISL29125_ReadRData();
		green = ISL29125_ReadGData();
		blue = ISL29125_ReadBData();
		blue = blue + (blue * 30 / 100);			//compensate for a low BLUE value by increasing it by 30% (* 30 / 100)
		
		// Display the the color values
		printf("R=%5d    G=%5d    B=%5d", red, green, blue);
		if((red > green) && (red > blue))
			printf("     Color = RED\n");
		else if((green > red) && (green > blue))
			printf("     Color = GREEN\n");
		else if((blue > red) && (blue > green))
			printf("     Color = BLUE\n");
		else
			printf("     Color = UNKNOWN\n");
		Delay(1000);		//create a delay so that ColorClick sensor can prepare for a next sample
  }
}



/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}
