/*#############################################################
File Name       : ex1_LIS3DSH_roll_pitch_swv.c
Author          : Grant Phillips
Date Modified   : 18/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use
									of the LIS3DSH 3D Accelerometer module found 
									on the STM32F4-Discovery board.  The roll and 
									pitch angles will be displayed as float values.
									
									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F4-Discovery Board
									* Make sure the LIS3DSH_F4.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
								
***************************************************************
NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB 
***************************************************************

The LIS3DSH_F4.c library makes use of floating point variables
which would normally be done by the hardware FPU of the STM32F4, 
but the Evaluation copy of Keil uVision does not support hardware
FPU and will make a program "freeze" when it does floating point
calculations.

To disable hardware FPU support and let the software handle the
floating point calculations (which will obviously decrease the
computational speed of the STM32F4), do the following:
1.  Right-click on "Demo" in the Project window and select
		"Option for Target Demo..."
2.  Select the "Target" tab
3.  Under "Floating Point Hardware", select "Not used"
4.  Click OK

The code can now be compiled and run like normal.
		
***************************************************************
NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB NB 
***************************************************************

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "LIS3DSH_F4.c"																					//for the LIS3DSH 3D Accelerometer on the STM32F4-Discovery board

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{ 
	RCC_ClocksTypeDef 			RCC_Clocks;									//structure used for setting up the SysTick Interrupt
	
	float Roll, Pitch;
	uint8_t ret;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																					//will end up in this infinite loop if there was an error with Systick_Config
		
	
  ret = LIS3DSH_Init();																//initialize the LIS3DSH module and check response
	if(ret == 1)
	{
		printf("LIS3DSH not found or is faulty ...\n");
		while(1);	//create infinite loop here to halt program when LIS3DSH is faulty
	}
	
	
	/* Main program loop */
	while(1)
	{
		/* Read LIS3DSH angles */
		LIS3DSH_ReadAngles(&Roll, &Pitch);
		
		/* Display angles in degrees*/
		printf("Roll = %10.3f     Pitch = %10.3f\n", Roll, Pitch);
		
		Delay(250);
  }
}



/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}












