/*#############################################################
File Name       : ex1_TCS3200_measure_swv.c
Author          : Grant Phillips
Date Modified   : 31/08/2015
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  a TCS3200 Color Sensor Module.  The sensor uses
									an output pulse with a varying frequency based
									on the amount of color detected for the selected
									color.  The TCS3200_ReadPulse(color) function
									reads the HIGH pulse for this value in nano 
									seconds (nS) from the sensor.
									This example makes and attempt to detect if an
									object is RED, GREEN, or BLUE by comparing the
									pulse values.  The results so far are 100%.
									
									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F4-Discovery Board
									* Make sure the TCS3200_F4.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									* The TCS3200 Color Sensor Module is 
										connected as:
										GND			-		GND
										VCC			-		3V
										S0			-		PD8
										S1			-		PD9
										S2			-		PD10
										S3			-		PD11
										OUT			-		PA1
										LED			-		PD7
								
See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "TCS3200_F4.c"																					//for the TCS3200 Color Sensor Module functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{ 
	RCC_ClocksTypeDef 			RCC_Clocks;									//structure used for setting up the SysTick Interrupt
	
	uint32_t red, green, blue, clear;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																					//will end up in this infinite loop if there was an error with Systick_Config
	
	TCS3200_Init();																			//initialize the TCS3200 color sensor module
	TCS3200_SetLEDs(1);																	//turn ON the white LEDs on the TCS3200 color sensor module
	
	/* Main program loop */
	while(1)
	{
		/* Read the HIGH pulse width in nS for each color.
		The lower the value, the more of that color is detected */
		red = TCS3200_ReadPulse(TCS3200_RED);
		green = TCS3200_ReadPulse(TCS3200_GREEN);
		blue = TCS3200_ReadPulse(TCS3200_BLUE);
		clear = TCS3200_ReadPulse(TCS3200_CLEAR);
		
		/* Display pulse values in nano seconds (nS) */
		printf("RED: %10d     GREEN: %10d     BLUE: %10d     CLEAR: %10d     ", red, green, blue, clear);
		
		/* Determine if the color detected is most likely RED, GREEN, or BLUE */
		if((red < green) && (red < blue))
			printf("RED\n");
		else if((green < red) && (green < blue))
			printf("GREEN\n");
		else if((blue < red) && (blue < green))
			printf("BLUE\n");
		else
			printf("????\n");
			
		Delay(10);
  }
}



/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}
